from distutils.core import setup
setup(
    name = 'pysendgrid',
    packages = ['pysendgrid'],
    version = '0.25.6',
    author = 'Nick Bagley',
    author_email = 'nick@thrivehive.com',
    url = 'https://github.com/teasea33/pysendgrid',
    license = 'GPLv3',
    classifiers = [
    "Programming Language :: Python",
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    "Operating System :: OS Independent",
    "Development Status :: 2 - Pre-Alpha"
    ]
    )
